@@ -17,6 +17,7 @@ US_SYMPTOM_SURVEY_DATA = '/home/j/Project/covid/data_intake/symptom_survey/us'
 GLOBAL_SYMPTOM_SURVEY_DATA = '/home/j/Project/covid/data_intake/symptom_survey/global'
 PULSE_SURVEY_DATA = '/home/j/Project/covid/data_intake/pulse_survey/US Census_pulse surveys'
 SOCIAL_DISTANCING_DATA = '/home/j/Project/covid/data_intake/social distancing'
+CFR_AGE_MAX_PLANCK_DATA = '/home/j/Project/covid/data_intake/CFR-age/MaxPlanck'
 
 # Shared paths
 EXEC_R_SCRIPT_PATH = Path('/share/singularity-images/lbd/shells/singR.sh')
@@ -69,6 +70,8 @@ GLOBAL_SYMPTOM_SURVEY_OUTPUT_DIR_NAME = Path('global')
 PULSE_SURVEY_OUTPUT_DIR_NAME = Path('pulse_survey')
 PULSE_SURVEY_US_CENSUS_OUTPUT_DIR_NAME = Path('US Census_pulse surveys')
 SOCIAL_DISTANCING_DIR_NAME = Path('social distancing')
+CFR_AGE_DIR_NAME = Path('cfr_age')
+CFR_AGE_MAX_PLANCK_DIR_NAME = Path('MaxPlanck')
 
 LOG_DIR = Path("logs")
 LOG_FILE_NAME = Path("master_log.txt")
